% Copyright 2011-2018 The MathWorks, Inc.

%disp('DEFINING PARAMETERS...');
% HEV SERIES PARALLEL PARAMETERS

% PREDEFINED LI-ION BATTERY PARAMS
HEV_Param.Battery_Det.Nominal_Voltage = 200;
HEV_Param.Battery_Det.Rated_Capacity = 8.1;      % Ampere-hours
HEV_Param.Battery_Det.Initial_SOC = 75.75;       % Percent
HEV_Param.Battery_Det.Series_Resistance = 0.2/10;   % Ohm


% FOR ACCEL TEST
%HEV_Param.Battery_Det.Initial_SOC = 97;         % Percent

% GENERIC BATTERY PARAMS
HEV_Param.Battery_Sys.Nominal_Voltage = 217;
HEV_Param.Battery_Sys.Internal_Resistance = 0.1;% Ohm
HEV_Param.Battery_Sys.Rated_Capacity = 60;     % Ampere-hours
HEV_Param.Battery_Sys.Initial_Charge = 60;    % Ampere-hours
HEV_Param.Battery_Sys.Expn_Voltage = 215.0342;       % V
HEV_Param.Battery_Sys.Expn_Charge = 2.3438;

HEV_Param.Battery_Sys.C1.Capacitance = 2500;
HEV_Param.Battery_Sys.C1.Initial_Voltage = 19;
HEV_Param.Battery_Sys.C1.Series_Resistance = 1e-6;
HEV_Param.Battery_Sys.R2 = 0.3;
HEV_Param.Battery_Sys.R1 = 1.8;
HEV_Param.Battery_Sys.Maximum_Capacity = HEV_Param.Battery_Sys.Rated_Capacity;    % Ampere-hours


% ULTRACAPACITOR PARAMETERS
HEV_Param.UltraCapacitor.Nominal_Capacitance = 1000; % Farad
HEV_Param.UltraCapacitor.Rate_C_V = 0.2;          % Farad/Volt
HEV_Param.UltraCapacitor.Series_R = 30/3;            % Ohm
HEV_Param.UltraCapacitor.Self_Discharge_R = 500;  % Ohm
HEV_Param.UltraCapacitor.Initial_Voltage = 217;     % Volt


% MOTOR PARAMETERS
HEV_Param.Motor.Stator_Resistance = 0.0065*14;        % Ampere-hours
HEV_Param.Motor.Stator_Resistance = 0.0065*14;
HEV_Param.Motor.TorqSpdLUT.SpeedRPM = [0 1000 2000 2778.17 4395 6005 7615 9207 10685 12011 14000];
HEV_Param.Motor.TorqSpdLUT.TorqueNm = [316 316 316 316 182 116.4 83.33 63.11 52.083 44.73 36.78];
HEV_Param.Motor.Damping = 1e-5; %N*m/(rad/s)
HEV_Param.Motor.TorqueControl_TimeConst = 0.02*2/1.5;
HEV_Param.Motor.Shaft_Inertia = 0.014;
HEV_Param.Motor.Series_Resistance = 0.01; %CHG
HEV_Param.Motor.Inductances = [0.001597972349731   0.002057052250467];
HEV_Param.Motor.Efficiency = 91;

% DC-DC CONVERTER PARAMETERS
HEV_Param.DCDCConv.Output_Voltage = 500;      % Volts
HEV_Param.DCDCConv.Resistance_Losses = 1000/40^2;      % Ohm
HEV_Param.DCDCConv.Kp = 0.01;
HEV_Param.DCDCConv.Ki = 10;
HEV_Param.DCDCConv.MinVin = 20;

HEV_Param.DCDCConv.Mean_Boost.Kp = 0.001;
HEV_Param.DCDCConv.Mean_Boost.Ki = 1;

HEV_Param.DCDCConv.EPower2Heat = 0.1;      % Watts/Watts
HEV_Param.DCDCConv.Thermal_Mass = 0.1*10;    % kg
HEV_Param.DCDCConv.Specific_Heat = 100;   % J/kg/K
HEV_Param.DCDCConv.Initial_Temperature = 25;     % C
HEV_Param.DCDCConv.Air_Temperature = 298;     % K
HEV_Param.DCDCConv.Convection.Area = 20;     % cm^2
HEV_Param.DCDCConv.Convection.HT_Coefficient = 100; % W/(m^2*K)


% CONTROLLER PARAMETERS
HEV_Param.Control.Engine_Start_RPM = 800; % RPM
HEV_Param.Control.Engine_Stop_RPM = 790; % RPM
HEV_Param.Control.Mode_Logic_TS = 0.1;
HEV_Param.Control.ICE.Kp = 0.02;
HEV_Param.Control.ICE.Ki = 0.01;
HEV_Param.Control.Gen.Kp = 10;
HEV_Param.Control.Gen.Ki = 3;
HEV_Param.Control.Mot.Kp = 1;
HEV_Param.Control.Mot.Ki = 0.5;
HEV_Param.Control.Veh_Spd.Kp = 10;
HEV_Param.Control.Veh_Spd.Ki = 15;


% VEHICLE PARAMETERS
HEV_Param.Vehicle.Mass = 1521;         % kg
HEV_Param.Vehicle.Tire_Radius = 0.4;    % m
HEV_Param.Vehicle.Wheel_Inertia = 1.39;  % kg*m^2
HEV_Param.Vehicle.Aero_Drag_Coeff = 0.26;
HEV_Param.Vehicle.Incline = 0;
HEV_Param.Vehicle.Engine_Vehicle_Gear_Ratio = 7.94;
HEV_Param.Vehicle.Distance_CG_FrontAxle = 1.51;
HEV_Param.Vehicle.Distance_CG_RearAxle = 1.19;
HEV_Param.Vehicle.Distance_CG_Ground = 0.5;
HEV_Param.Vehicle.Frontal_Area = 2.16;
HEV_Param.Vehicle.Tire.Rated_Vertical_Load = 3000;  % N
HEV_Param.Vehicle.Tire.Rated_Peak_Long_Force = 3500;  % N
HEV_Param.Vehicle.Tire.Slip_At_Peak_Force = 6;  % Percent
%HEV_Param.Vehicle.Tire.Relaxation_Length = 0.2*0.09;  % Percent
%HEV_Param.Vehicle.Tire.Relaxation_Length = 0.2;
HEV_Param.Vehicle.Tire.Relaxation_Length = 0.25;
HEV_Param.Vehicle.Trans.Inertia = 0.5;
HEV_Param.Vehicle.Trans.Friction =  0.1*0.001;%18/36


% Battery Model Parameters - 50Ah
HEV_Param.Battery_Cell.NominalCap = 50; %(Ah)
    
% Battery Block Initial Conditions
% Initial State of Charge (% of full charge)
% Initial Electrolyte Temperature (C, typically same as ambient temp)
HEV_Param.Battery_Cell.SOC_init = 0.8;
HEV_Param.Battery_Cell.theta_init = 25;
    
% Battery Block Thermal Parameters
HEV_Param.Battery_Cell.Ctheta = 400; %(J/C) Thermal Capacitance
HEV_Param.Battery_Cell.Area = 0.01; % (m^2) Surface area of battery exposed to air
HEV_Param.Battery_Cell.Rtheta = 20;  %(W/m^2/K) Convective heat transfer coefficient
    
% Battery Block Capacity Parameters
% Charge/discharge cycles at ranges of current/temp
HEV_Param.Battery_Cell.Kc = 1.2; %()
HEV_Param.Battery_Cell.Costar = 1.8e+005; %(As)
HEV_Param.Battery_Cell.Kt_Temps = [25 40 60 75]; % Temperature breakpoints for Kt LUT
HEV_Param.Battery_Cell.Kt = [0.80,1.10,1.20,1.12;]; %() LUT output values
HEV_Param.Battery_Cell.delta = 0.73; %()
HEV_Param.Battery_Cell.Istar = 15; %(A) Nominal Current (=cap/disch_t)
HEV_Param.Battery_Cell.theta_f = -40; %(C) Electrolyte Freezing Temp
    
% Battery Block Parasitic Branch Parameters
% End of charge cycle at ranges of current/temp
HEV_Param.Battery_Cell.Ep = 1.95; %(V) Parasitic emf
HEV_Param.Battery_Cell.Gpo = 2.0e-011; %(s)
HEV_Param.Battery_Cell.Vpo = 0.12; %(V)
HEV_Param.Battery_Cell.Ap = 2.0; %()
HEV_Param.Battery_Cell.Taup = 3; % (s)
    
% Battery Block Main Branch Parameters
HEV_Param.Battery_Cell.Emo = 2.18*10; % (V) [max o.c. volts per cell]
HEV_Param.Battery_Cell.Ke = 0.0006; %(V/C)
HEV_Param.Battery_Cell.Ao = -0.6; % ()
HEV_Param.Battery_Cell.Roo = 0.0042; % (Ohm)
HEV_Param.Battery_Cell.R10 = 0.0010; %(Ohm)
HEV_Param.Battery_Cell.A21 = -10.0; %()
HEV_Param.Battery_Cell.A22 = -8.75; %()
HEV_Param.Battery_Cell.R20 = 0.11; %(Ohm)
HEV_Param.Battery_Cell.Tau1 = 100; %(s)
    
% Battery Block Number Of Cells Parameters
HEV_Param.Battery_Cell.ns = 6; %() Number of cells in series in each parallel branch
    
% Compute initial extracted charge
HEV_Param.Battery_Cell.Qe_init = (1-HEV_Param.Battery_Cell.SOC_init)*HEV_Param.Battery_Cell.Kc*HEV_Param.Battery_Cell.Costar*interp1([HEV_Param.Battery_Cell.theta_f HEV_Param.Battery_Cell.Kt_Temps],[0 HEV_Param.Battery_Cell.Kt],HEV_Param.Battery_Cell.theta_init,'spline');
EV_eta2=[0.00100000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000;0.00100000000000000,0.0291000000000000,0.0582000000000000,0.0873000000000000,0.116000000000000,0.145000000000000,0.175000000000000,0.204000000000000,0.321000000000000,0.439000000000000,0.556000000000000,0.653000000000000,0.649000000000000,0.644000000000000,0.638000000000000;0.00100000000000000,0.0582000000000000,0.116000000000000,0.175000000000000,0.233000000000000,0.291000000000000,0.349000000000000,0.407000000000000,0.642000000000000,0.767000000000000,0.777000000000000,0.783000000000000,0.785000000000000,0.784000000000000,0.780000000000000;0.00100000000000000,0.0873000000000000,0.175000000000000,0.262000000000000,0.272000000000000,0.436000000000000,0.524000000000000,0.611000000000000,0.804000000000000,0.826000000000000,0.840000000000000,0.846000000000000,0.847000000000000,0.845000000000000,0.839000000000000;0.00100000000000000,0.116000000000000,0.233000000000000,0.349000000000000,0.465000000000000,0.582000000000000,0.698000000000000,0.806000000000000,0.842000000000000,0.866000000000000,0.878000000000000,0.881000000000000,0.880000000000000,0.874000000000000,0.866000000000000;0.00100000000000000,0.145000000000000,0.291000000000000,0.436000000000000,0.582000000000000,0.727000000000000,0.817000000000000,0.831000000000000,0.870000000000000,0.892000000000000,0.901000000000000,0.901000000000000,0.896000000000000,0.888000000000000,0.877000000000000;0.00100000000000000,0.175000000000000,0.349000000000000,0.524000000000000,0.698000000000000,0.820000000000000,0.837000000000000,0.851000000000000,0.891000000000000,0.910000000000000,0.915000000000000,0.912000000000000,0.904000000000000,0.893000000000000,0.871000000000000;0.00100000000000000,0.205000000000000,0.409000000000000,0.614000000000000,0.814000000000000,0.836000000000000,0.853000000000000,0.868000000000000,0.907000000000000,0.923000000000000,0.923000000000000,0.917000000000000,0.907000000000000,0.886000000000000,0.00100000000000000;0.00100000000000000,0.246000000000000,0.491000000000000,0.737000000000000,0.831000000000000,0.854000000000000,0.872000000000000,0.887000000000000,0.923000000000000,0.933000000000000,0.929000000000000,0.919000000000000,0.897000000000000,0.00100000000000000,0.00100000000000000;0.00100000000000000,0.305000000000000,0.609000000000000,0.819000000000000,0.851000000000000,0.875000000000000,0.894000000000000,0.908000000000000,0.937000000000000,0.939000000000000,0.930000000000000,0.907000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000;0.00100000000000000,0.397000000000000,0.790000000000000,0.840000000000000,0.874000000000000,0.898000000000000,0.915000000000000,0.927000000000000,0.946000000000000,0.939000000000000,0.914000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000;0.00100000000000000,0.558000000000000,0.808000000000000,0.864000000000000,0.898000000000000,0.919000000000000,0.932000000000000,0.939000000000000,0.945000000000000,0.917000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000;0.00100000000000000,0.683000000000000,0.814000000000000,0.873000000000000,0.902000000000000,0.918000000000000,0.926000000000000,0.932000000000000,0.911000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000;0.00100000000000000,0.527000000000000,0.691000000000000,0.766000000000000,0.809000000000000,0.838000000000000,0.859000000000000,0.872000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000,0.00100000000000000];
Ts=1e-4;
decimation=2;

%Leaf Motor Maps

Leaf_omega_axis=[+0.000000E+00	+3.935365E+01	+7.870730E+01	+1.180610E+02	+1.574146E+02	+1.967683E+02	+2.361219E+02	+2.754756E+02	+3.857216E+02	+4.959676E+02	+6.062136E+02	+7.164596E+02	+8.267056E+02	+9.369516E+02	+1.047198E+03];
Leaf_torque_axis=[+0.000000E+00	+1.167089E+01	+2.334179E+01	+3.501268E+01	+4.668357E+01	+5.835446E+01	+7.002536E+01	+7.910792E+01	+9.076234E+01	+1.063042E+02	+1.281510E+02	+1.612785E+02	+2.121831E+02	+2.805757E+02];

Leaf_Id=[+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00;
-0.000000E+00	-7.425338E-06	-0.000000E+00	-6.289305E-03	-0.000000E+00	-2.293242E+02	-9.477225E-01	-8.779932E-01	-1.473796E+02	-2.432033E+01	-4.812830E+01	-6.521869E+01	-7.820143E+01	-8.843910E+01	-9.674246E+01;
-2.905778E-06	-0.000000E+00	-1.107552E+01	-7.254693E+00	-3.496266E+00	-3.503976E+00	-3.506814E+00	-3.501088E+00	-1.028702E+01	-3.104879E+01	-5.390181E+01	-7.069480E+01	-8.369836E+01	-9.412604E+01	-1.027148E+02;
-1.386320E+00	-2.538734E+00	-2.519598E+00	-4.433452E+00	-8.575794E+00	-8.579960E+00	-9.728894E+00	-1.198115E+01	-1.242891E+01	-3.874224E+01	-6.136772E+01	-7.837845E+01	-9.182110E+01	-1.028208E+02	-1.120787E+02;
-1.136848E+01	-1.208010E+01	-1.088093E+01	-1.088892E+01	-1.521486E+01	-1.522125E+01	-1.474445E+01	-1.475177E+01	-2.038170E+01	-4.724026E+01	-7.024896E+01	-8.797407E+01	-1.023285E+02	-1.144132E+02	-1.249651E+02;
-1.219211E+01	-1.562461E+01	-1.892328E+01	-2.019895E+01	-2.029215E+01	-2.029662E+01	-2.026550E+01	-2.027105E+01	-2.529528E+01	-5.654833E+01	-8.049212E+01	-9.946243E+01	-1.153506E+02	-1.293914E+02	-1.427060E+02;
-2.429565E+01	-2.434491E+01	-2.437496E+01	-2.638546E+01	-2.663661E+01	-2.664754E+01	-2.773417E+01	-2.814517E+01	-3.252712E+01	-6.672769E+01	-9.215918E+01	-1.130370E+02	-1.315085E+02	-1.497925E+02	-1.825875E+02;
-2.958260E+01	-3.025203E+01	-3.065077E+01	-3.062741E+01	-3.144955E+01	-3.172657E+01	-3.279417E+01	-3.379938E+01	-4.006104E+01	-7.530483E+01	-1.023175E+02	-1.253533E+02	-1.474693E+02	-1.858648E+02	0;
-3.611475E+01	-3.671883E+01	-3.673919E+01	-3.757394E+01	-3.795127E+01	-3.816951E+01	-3.869462E+01	-3.964260E+01	-5.012848E+01	-8.722867E+01	-1.169552E+02	-1.444126E+02	-1.908155E+02	0 0;
-4.508691E+01	-4.534806E+01	-4.566672E+01	-4.568682E+01	-4.660740E+01	-4.651275E+01	-4.743752E+01	-4.734773E+01	-6.438975E+01	-1.049265E+02	-1.402240E+02	-1.967646E+02	0	0  0;
-5.695225E+01	-5.795593E+01	-5.806686E+01	-5.833830E+01	-5.832214E+01	-5.953367E+01	-5.953303E+01	-5.968741E+01	-8.631059E+01	-1.341524E+02	-2.056751E+02	0	0	0	0;
-7.621394E+01	-7.678027E+01	-7.676156E+01	-7.704545E+01	-7.723855E+01	-7.758344E+01	-7.766520E+01	-7.843380E+01	-1.244303E+02	-2.186492E+02	0	0	0	0	0;
-1.084495E+02	-1.089663E+02	-1.090405E+02	-1.092254E+02	-1.094893E+02	-1.094144E+02	-1.094730E+02	-1.097200E+02	-2.072028E+02	0	0	0	0	0	0;
-1.595495E+02	-1.600178E+02	-1.601579E+02	-1.604478E+02	-1.603095E+02	-1.603922E+02	-1.604257E+02	-1.605923E+02	0	0 0	0	0	0	0];

Leaf_Iq=[+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00;
+1.328106E+01	+1.365579E+01	+1.369622E+01	+1.373763E+01	+1.377693E+01	+5.198945E+00	+1.399545E+01	+1.402597E+01	+6.885450E+00	+1.296258E+01	+1.017967E+01	+9.207555E+00	+8.997430E+00	+8.992968E+00	+9.006921E+00;
+2.402541E+01	+2.440526E+01	+2.368096E+01	+2.416311E+01	+2.447588E+01	+2.451333E+01	+2.455088E+01	+2.458888E+01	+2.404993E+01	+2.065284E+01	+1.774254E+01	+1.675881E+01	+1.641110E+01	+1.620989E+01	+1.601595E+01;
+3.408775E+01	+3.437615E+01	+3.441959E+01	+3.422369E+01	+3.359552E+01	+3.363286E+01	+3.345556E+01	+3.304301E+01	+3.305114E+01	+2.749863E+01	+2.458478E+01	+2.351258E+01	+2.294765E+01	+2.248116E+01	+2.201830E+01;
+4.205157E+01	+4.225755E+01	+4.262317E+01	+4.265859E+01	+4.151019E+01	+4.154757E+01	+4.172161E+01	+4.175903E+01	+4.024665E+01	+3.380111E+01	+3.085196E+01	+2.956355E+01	+2.866422E+01	+2.783004E+01	+2.700351E+01;
+5.166976E+01	+5.091477E+01	+4.978063E+01	+4.936678E+01	+4.937535E+01	+4.941567E+01	+4.946866E+01	+4.950882E+01	+4.783915E+01	+3.965088E+01	+3.654557E+01	+3.488170E+01	+3.350785E+01	+3.217560E+01	+3.083963E+01;
+5.694476E+01	+5.735370E+01	+5.738665E+01	+5.657240E+01	+5.651054E+01	+5.655056E+01	+5.613711E+01	+5.600906E+01	+5.435503E+01	+4.503814E+01	+4.161041E+01	+3.940030E+01	+3.739615E+01	+3.537316E+01	+3.247448E+01;
+6.221762E+01	+6.233803E+01	+6.219631E+01	+6.225440E+01	+6.191432E+01	+6.183119E+01	+6.138297E+01	+6.097012E+01	+5.841627E+01	+4.888147E+01	+4.507948E+01	+4.232923E+01	+3.970432E+01	+3.611543E+01	0;
+6.881362E+01	+6.894362E+01	+6.898275E+01	+6.859467E+01	+6.844790E+01	+6.838393E+01	+6.816289E+01	+6.772999E+01	+6.313337E+01	+5.333223E+01	+4.890330E+01	+4.532306E+01	+4.076184E+01	0	0;
+7.700009E+01	+7.731370E+01	+7.717250E+01	+7.721401E+01	+7.673299E+01	+7.683994E+01	+7.636399E+01	+7.646695E+01	+6.863031E+01	+5.841557E+01	+5.296459E+01	+4.707695E+01	0 0	0;
+8.819107E+01	+8.801012E+01	+8.799667E+01	+8.787907E+01	+8.794797E+01	+8.723197E+01	+8.728979E+01	+8.724961E+01	+7.506396E+01	+6.416190E+01	+5.610379E+01	0	0	0	0;
+1.033962E+02	+1.034992E+02	+1.035823E+02	+1.034426E+02	+1.033704E+02	+1.031884E+02	+1.031976E+02	+1.027140E+02	+8.314651E+01	+7.016962E+01	0	0	0	0	0;
+1.262549E+02	+1.264856E+02	+1.265164E+02	+1.264521E+02	+1.263211E+02	+1.264796E+02	+1.265242E+02	+1.264076E+02	+9.898601E+01	0	0	0	0	0	0;
+1.633424E+02	+1.638844E+02	+1.638834E+02	+1.637374E+02	+1.640067E+02	+1.640613E+02	+1.641649E+02	+1.641382E+02	0	0	0	0	0	0	0];

Leaf_iq_axis=[+0.000000E+00	+2.551476E+01	+5.102952E+01	+7.654428E+01	+1.020590E+02	+1.275738E+02	+1.530886E+02	+1.786033E+02	+2.041181E+02	+2.296328E+02];
Leaf_id_axis=[-2.296328E+02	-2.041181E+02	-1.786033E+02	-1.530886E+02	-1.275738E+02	-1.020590E+02	-7.654428E+01	-5.102952E+01	-2.551476E+01	+0.000000E+00];

Leaf_phid=[-4.199708E-02	-2.553401E-02	-8.247090E-03	+9.778563E-03	+2.810579E-02	+4.661402E-02	+6.539149E-02	+8.441129E-02	+1.036049E-01	+1.229854E-01;
-4.169034E-02	-2.517095E-02	-7.722892E-03	+1.018374E-02	+2.855121E-02	+4.717291E-02	+6.597003E-02	+8.492636E-02	+1.041785E-01	+1.235814E-01;
-4.071675E-02	-2.390941E-02	-6.289560E-03	+1.171133E-02	+3.003486E-02	+4.866957E-02	+6.753366E-02	+8.657693E-02	+1.057410E-01	+1.247637E-01;
-3.868113E-02	-2.151324E-02	-3.824432E-03	+1.414281E-02	+3.237960E-02	+5.099736E-02	+6.983563E-02	+8.847866E-02	+1.059705E-01	+1.223502E-01;
-3.478261E-02	-1.759886E-02	-1.667091E-04	+1.758444E-02	+3.556885E-02	+5.350446E-02	+7.043992E-02	+8.635342E-02	+1.017845E-01	+1.169405E-01;
-2.947851E-02	-1.231885E-02	+5.063069E-03	+2.239088E-02	+3.875631E-02	+5.303588E-02	+6.704816E-02	+8.153225E-02	+9.623810E-02	+1.109697E-01;
-2.391567E-02	-6.715432E-03	+1.025715E-02	+2.596362E-02	+3.920042E-02	+5.114334E-02	+6.317644E-02	+7.644829E-02	+9.062171E-02	+1.050741E-01;
-1.838972E-02	-1.952129E-03	+1.322802E-02	+2.721158E-02	+3.886626E-02	+4.944719E-02	+6.022230E-02	+7.180415E-02	+8.515806E-02	+9.926141E-02;
-1.436886E-02	+2.375525E-04	+1.437689E-02	+2.764286E-02	+3.859122E-02	+4.841387E-02	+5.802379E-02	+6.818488E-02	+8.009835E-02	+9.361248E-02;
-1.274459E-02	+1.239457E-03	+1.504183E-02	+2.784216E-02	+3.832260E-02	+4.772370E-02	+5.666796E-02	+6.569922E-02	+7.587386E-02	+8.830686E-02];

Leaf_phiq=[-1.952292E-05	-3.396145E-06	+2.962394E-07	-2.077424E-05	-3.654397E-05	-1.649631E-05	+3.339687E-05	+4.306712E-05	+9.669480E-06	-2.373166E-05;
+3.707585E-02	+3.779322E-02	+3.871019E-02	+3.968179E-02	+4.057700E-02	+4.155799E-02	+4.265458E-02	+4.375677E-02	+4.486604E-02	+4.593300E-02;
+7.336423E-02	+7.489475E-02	+7.669512E-02	+7.871617E-02	+8.078254E-02	+8.270869E-02	+8.468316E-02	+8.671160E-02	+8.874675E-02	+9.013579E-02;
+1.071657E-01	+1.101472E-01	+1.132222E-01	+1.161502E-01	+1.189125E-01	+1.216234E-01	+1.241261E-01	+1.258805E-01	+1.248251E-01	+1.211350E-01;
+1.330957E-01	+1.380737E-01	+1.428271E-01	+1.472507E-01	+1.511401E-01	+1.539410E-01	+1.537610E-01	+1.506123E-01	+1.458624E-01	+1.402086E-01;
+1.516151E-01	+1.571132E-01	+1.626543E-01	+1.678796E-01	+1.714861E-01	+1.713722E-01	+1.683195E-01	+1.636628E-01	+1.582585E-01	+1.524640E-01;
+1.664230E-01	+1.720304E-01	+1.771359E-01	+1.804481E-01	+1.813657E-01	+1.801951E-01	+1.776104E-01	+1.733037E-01	+1.679980E-01	+1.622654E-01;
+1.794002E-01	+1.838842E-01	+1.864066E-01	+1.875761E-01	+1.877125E-01	+1.869243E-01	+1.849243E-01	+1.816047E-01	+1.767460E-01	+1.711821E-01;
+1.893878E-01	+1.911981E-01	+1.922346E-01	+1.928076E-01	+1.927926E-01	+1.922946E-01	+1.910691E-01	+1.886951E-01	+1.847663E-01	+1.795792E-01;
+1.953971E-01	+1.963399E-01	+1.970236E-01	+1.973928E-01	+1.972968E-01	+1.968341E-01	+1.959967E-01	+1.945678E-01	+1.918955E-01	+1.874661E-01];

Leaf_Ld=[+4.562516E-04	+4.676675E-04	+4.893199E-04	+5.037353E-04	+5.104223E-04	+5.166612E-04	+5.237499E-04	+5.295159E-04	+5.345150E-04	+5.371060E-04;
+4.578125E-04	+4.706808E-04	+4.899036E-04	+5.026437E-04	+5.125522E-04	+5.185058E-04	+5.231427E-04	+5.294482E-04	+5.356365E-04	+5.377254E-04;
+4.657924E-04	+4.770513E-04	+4.935902E-04	+5.033409E-04	+5.121236E-04	+5.196141E-04	+5.252754E-04	+5.294316E-04	+5.291468E-04	+5.271886E-04;
+4.757846E-04	+4.830029E-04	+4.940794E-04	+5.016728E-04	+5.106868E-04	+5.190213E-04	+5.193717E-04	+5.007151E-04	+4.693516E-04	+4.539394E-04;
+4.762243E-04	+4.796663E-04	+4.875286E-04	+4.951812E-04	+4.977372E-04	+4.832021E-04	+4.551821E-04	+4.343357E-04	+4.238390E-04	+4.200275E-04;
+4.755566E-04	+4.786364E-04	+4.809665E-04	+4.668811E-04	+4.246422E-04	+3.920351E-04	+3.948691E-04	+4.044797E-04	+4.079094E-04	+4.082660E-04;
+4.766810E-04	+4.735265E-04	+4.528277E-04	+4.010616E-04	+3.489108E-04	+3.322315E-04	+3.506460E-04	+3.803041E-04	+3.966632E-04	+4.005292E-04;
+4.555453E-04	+4.381212E-04	+4.041162E-04	+3.552644E-04	+3.081148E-04	+2.959269E-04	+3.097965E-04	+3.455302E-04	+3.804702E-04	+3.908552E-04;
+4.047967E-04	+3.983245E-04	+3.797504E-04	+3.355336E-04	+2.878200E-04	+2.692736E-04	+2.739634E-04	+3.058832E-04	+3.523456E-04	+3.745258E-04;
+3.875487E-04	+3.850314E-04	+3.686288E-04	+3.225974E-04	+2.754949E-04	+2.542083E-04	+2.490835E-04	+2.661327E-04	+3.132701E-04	+3.445637E-04];

Leaf_Lq=[+1.028048E-03	+1.047482E-03	+1.072792E-03	+1.100303E-03	+1.125549E-03	+1.152180E-03	+1.181188E-03	+1.211466E-03	+1.243133E-03	+1.273628E-03;
+1.016865E-03	+1.037850E-03	+1.062746E-03	+1.091044E-03	+1.119895E-03	+1.146308E-03	+1.172976E-03	+1.200950E-03	+1.229614E-03	+1.249324E-03;
+9.712230E-04	+1.002596E-03	+1.032499E-03	+1.059608E-03	+1.085481E-03	+1.109452E-03	+1.128936E-03	+1.137973E-03	+1.107978E-03	+1.042060E-03;
+8.276885E-04	+8.754587E-04	+9.163785E-04	+9.496711E-04	+9.749314E-04	+9.870526E-04	+9.571987E-04	+8.854608E-04	+7.914406E-04	+6.938495E-04;
+6.159271E-04	+6.507996E-04	+6.849715E-04	+7.168050E-04	+7.285025E-04	+6.893593E-04	+6.123796E-04	+5.235422E-04	+4.632809E-04	+4.341198E-04;
+4.618102E-04	+4.705327E-04	+4.754113E-04	+4.600099E-04	+4.188310E-04	+3.637995E-04	+3.304774E-04	+3.144298E-04	+3.067291E-04	+3.056369E-04;
+3.850125E-04	+3.709606E-04	+3.291314E-04	+2.729310E-04	+2.248469E-04	+2.155039E-04	+2.300898E-04	+2.486181E-04	+2.561777E-04	+2.593744E-04;
+3.182184E-04	+2.656027E-04	+2.092196E-04	+1.712638E-04	+1.583408E-04	+1.676606E-04	+1.864945E-04	+2.132760E-04	+2.323564E-04	+2.399142E-04;
+2.216667E-04	+1.725967E-04	+1.471189E-04	+1.360281E-04	+1.328077E-04	+1.373178E-04	+1.534279E-04	+1.796271E-04	+2.099239E-04	+2.256439E-04;
+1.665415E-04	+1.424993E-04	+1.327223E-04	+1.270707E-04	+1.248274E-04	+1.258053E-04	+1.365616E-04	+1.627539E-04	+1.975748E-04	+2.185754E-04];

Leaf_T=[-3.804040E-02	-5.882121E-03	+4.489506E-04	-2.698573E-02	-3.955883E-02	-1.428580E-02	+2.169126E-02	+1.864805E-02	+2.093441E-03	+0.000000E+00;
+6.321631E+01	+6.000831E+01	+5.699326E+01	+5.375141E+01	+5.010591E+01	+4.620214E+01	+4.198665E+01	+3.733322E+01	+3.226814E+01	+2.675537E+01;
+1.253198E+02	+1.193649E+02	+1.135080E+02	+1.073233E+02	+1.004522E+02	+9.269961E+01	+8.424375E+01	+7.503390E+01	+6.499948E+01	+5.402265E+01;
+1.836890E+02	+1.768020E+02	+1.691042E+02	+1.600648E+02	+1.497533E+02	+1.384486E+02	+1.259781E+02	+1.119731E+02	+9.585246E+01	+7.946641E+01;
+2.292152E+02	+2.239029E+02	+2.163100E+02	+2.065067E+02	+1.944117E+02	+1.796477E+02	+1.608687E+02	+1.399971E+02	+1.197245E+02	+1.012704E+02;
+2.635115E+02	+2.587848E+02	+2.519832E+02	+2.423136E+02	+2.275873E+02	+2.058195E+02	+1.819031E+02	+1.591246E+02	+1.384407E+02	+1.201246E+02;
+2.932087E+02	+2.892332E+02	+2.817734E+02	+2.681287E+02	+2.472496E+02	+2.224841E+02	+1.974241E+02	+1.743467E+02	+1.540891E+02	+1.364912E+02;
+3.216915E+02	+3.155288E+02	+3.025461E+02	+2.849004E+02	+2.621005E+02	+2.368136E+02	+2.113752E+02	+1.874539E+02	+1.673225E+02	+1.504306E+02;
+3.441351E+02	+3.315664E+02	+3.162321E+02	+2.983344E+02	+2.755379E+02	+2.503799E+02	+2.245965E+02	+1.998011E+02	+1.787322E+02	+1.621367E+02;
+3.558983E+02	+3.424757E+02	+3.278982E+02	+3.106635E+02	+2.882453E+02	+2.634479E+02	+2.377173E+02	+2.122627E+02	+1.893855E+02	+1.720658E+02];

Leaf_Eff=[+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00	+0.000000E+00;
+0.000000E+00	+9.184608E-01	+9.393599E-01	+9.444175E-01	+9.453740E-01	+2.383765E-01	+9.432145E-01	+9.412644E-01	+5.831678E-01	+9.249252E-01	+9.006813E-01	+8.780970E-01	+8.602383E-01	+8.460774E-01	+8.343999E-01;
+0.000000E+00	+9.027720E-01	+9.345091E-01	+9.496303E-01	+9.554674E-01	+9.578728E-01	+9.589007E-01	+9.591354E-01	+9.582536E-01	+9.528296E-01	+9.396962E-01	+9.274245E-01	+9.173979E-01	+9.091550E-01	+9.021226E-01;
+0.000000E+00	+8.833714E-01	+9.309135E-01	+9.473549E-01	+9.552625E-01	+9.594983E-01	+9.619744E-01	+9.634447E-01	+9.646984E-01	+9.608786E-01	+9.513281E-01	+9.424756E-01	+9.350894E-01	+9.288343E-01	+9.233196E-01;
+0.000000E+00	+8.658247E-01	+9.226114E-01	+9.426169E-01	+9.525996E-01	+9.582889E-01	+9.617859E-01	+9.640220E-01	+9.670617E-01	+9.636120E-01	+9.555565E-01	+9.481078E-01	+9.417226E-01	+9.360913E-01	+9.308658E-01;
+0.000000E+00	+8.484201E-01	+9.137847E-01	+9.372140E-01	+9.490165E-01	+9.559216E-01	+9.603091E-01	+9.632341E-01	+9.675982E-01	+9.640335E-01	+9.565567E-01	+9.495780E-01	+9.433270E-01	+9.374119E-01	+9.312747E-01;
+0.000000E+00	+8.324902E-01	+9.048406E-01	+9.314273E-01	+9.449712E-01	+9.530125E-01	+9.582306E-01	+9.617970E-01	+9.672432E-01	+9.631352E-01	+9.556815E-01	+9.485269E-01	+9.415900E-01	+9.338761E-01	+9.159401E-01;
+0.000000E+00	+8.204564E-01	+8.980454E-01	+9.268736E-01	+9.416897E-01	+9.505578E-01	+9.563580E-01	+9.603646E-01	+9.664952E-01	+9.617888E-01	+9.540359E-01	+9.462706E-01	+9.377818E-01	+9.180111E-01	0;
+0.000000E+00	+8.058269E-01	+8.895408E-01	+9.210929E-01	+9.374413E-01	+9.473037E-01	+9.538048E-01	+9.583407E-01	+9.650551E-01	+9.593756E-01	+9.508005E-01	+9.412448E-01	+9.185870E-01	0	0;
+0.000000E+00	+7.877668E-01	+8.787617E-01	+9.136155E-01	+9.318547E-01	+9.429384E-01	+9.503058E-01	+9.554834E-01	+9.624288E-01	+9.550229E-01	+9.441903E-01	+9.180887E-01	0	0	0;
+0.000000E+00	+7.648515E-01	+8.646197E-01	+9.036308E-01	+9.242565E-01	+9.369017E-01	+9.453724E-01	+9.513780E-01	+9.574279E-01	+9.463406E-01	+9.151882E-01	0	0	0	0;
+0.000000E+00	+7.332343E-01	+8.443260E-01	+8.889799E-01	+9.129234E-01	+9.277519E-01	+9.377660E-01	+9.449280E-01	+9.464727E-01	+9.089788E-01	0	0	0	0	0;
+0.000000E+00	+6.837671E-01	+8.107833E-01	+8.640900E-01	+8.932916E-01	+9.116389E-01	+9.241739E-01	+9.332357E-01	+9.130064E-01	0	0	0	0	0	0;
+0.000000E+00	+6.036907E-01	+7.518411E-01	+8.186734E-01	+8.566339E-01	+8.810446E-01	+8.980169E-01	+9.104677E-01	0	0	0	0	0	0	0];

